@@ -2,7 +2,7 @@ package Test::GreaterVersion;
 
 =head1 NAME
 
-Test::GreaterVersion -- Did you update the VERSION?
+Test::GreaterVersion -- Test if you incremented VERSION
 
 =head1 SYNOPSIS
 
@@ -12,8 +12,9 @@ Test::GreaterVersion -- Did you update the VERSION?
   
 =head1 DESCRIPTION
 
-You might have forgotten to update the version of your module.
-This module provides two tests to check that.
+There are two functions which are supposed to be used
+in your test suites to assure that you incremented your
+version before your install the module or upload it to CPAN.
 
 C<has_greater_version> checks if your module source has a greater
 VERSION number than the version installed in the system.
@@ -24,6 +25,28 @@ a greater VERSION number than the version found on CPAN.
 The version is checked by looking for the VERSION scalar in the
 module. The names of these two functions are always exported.
 
+The two test functions expect your module files layed out in
+the standard way, i.e. tests are called in the top directory and
+module if found in the C<lib> directory:
+
+  Module Path
+    doc
+    examples
+    lib
+    t
+
+The version of My::Module is therefore expected in the file
+C<lib/My/Module.pm>. There's currently no way to alter that
+location. (The file name is OS independent via the magic of
+L<File::Spec>.)
+
+The version information is actually parsed by
+L<ExtUtils::MakeMaker>.
+
+The version numbers are compared calling
+C<CPAN::Version::vgt()>. See L<CPAN::Version> or L<version>
+for version number syntax. (Short: Both 1.00203 and v1.2.30 work.)  
+
 =cut
 
 use strict;
@@ -40,7 +63,7 @@ use base qw(Exporter);
 our @EXPORT = qw(has_greater_version
   has_greater_version_than_cpan);
 
-our $VERSION = 0.007;
+our $VERSION = 0.008;
 
 our $Test = Test::Builder->new;
 
@@ -79,10 +102,8 @@ sub has_greater_version {
 		return $Test->diag('Getting version from module in lib failed');
 	}
 
-	$Test->ok(
-		CPAN::Version->vgt($version_from_lib, $version_installed),
-		"$module has greater version"
-	);
+	$Test->ok( CPAN::Version->vgt( $version_from_lib, $version_installed ),
+		"$module has greater version" );
 }
 
 =head2 has_greater_version_than_cpan ($module)
@@ -96,6 +117,11 @@ has been an error in getting the module information from CPAN.
 As a result this function should only be called if you are
 sure that there's a version of the module on CPAN.
 
+Depending on the configuration of your CPAN shell the first
+call of this function may seem to block the test. When
+you notice this behaviour it's likely that the CPAN shell is
+trying to get the latest module index which may take some time.
+
 =cut
 
 sub has_greater_version_than_cpan {
@@ -115,10 +141,8 @@ sub has_greater_version_than_cpan {
 		return $Test->diag("Getting version of '$module' in lib failed");
 	}
 
-	$Test->ok(
-		CPAN::Version->vgt($version_from_lib, $version_on_cpan),
-		"$module has greater version than on CPAN"
-	);
+	$Test->ok( CPAN::Version->vgt( $version_from_lib, $version_on_cpan ),
+		"$module has greater version than on CPAN" );
 }
 
 =head2 _get_installed_version ($module)
@@ -129,13 +153,21 @@ information is found with the help of the CPAN module.
 Returns 0 if CPAN cannot find the module or it has no
 VERSION. Returns the version otherwise.
 
+We don't use CPAN::Shell::inst_version() since it doesn't
+remove blib before searching for the version and
+we want to have a diag() output in the test. And because
+the manpage doesn't list the function in the stable
+interface.
+
 =cut
 
 sub _get_installed_version {
 	my ($module) = @_;
 
-	# strip blib from @INC
-	# localize @INC so we won't affect others
+	# Strip blib from @INC so the CPAN::Shell
+	# won't find the module even if it's there.
+	# (Tests add blib to @INC).
+	# Localize @INC so we won't affect others
 	local @INC = grep { $_ !~ /blib/ } @INC;
 
 	# taken from CPAN manpage
@@ -145,18 +177,24 @@ sub _get_installed_version {
 	return $Test->diag("CPAN-version of '$module' not available")
 	  unless $m;
 
-    my $file = _module_to_file($module);
-    my $bestv;
-    for my $incdir (@INC) {
-        my $bfile = File::Spec->catfile($incdir, $file);
-        next unless -f $bfile;
-        my $foundv = MM->parse_version($bfile);
-        if (!$bestv || CPAN::Version->vgt($foundv,$bestv)) {
-            $bestv = $foundv;
-        }
-    }
-	# get installed version
-	return $m->inst_version();
+	my $file = _module_to_file($module);
+	my $bestv;
+	for my $incdir (@INC) {
+		my $bfile = File::Spec->catfile( $incdir, $file );
+
+		# skip if it's not a file
+		next unless -f $bfile;
+
+		# get the version
+		my $foundv = MM->parse_version($bfile);
+
+		# remember which version is greatest
+		if ( !$bestv || CPAN::Version->vgt( $foundv, $bestv ) ) {
+			$bestv = $foundv;
+		}
+	}
+
+	return $bestv;
 }
 
 =head2 _get_version_from_lib ($module)
@@ -195,7 +233,7 @@ sub _module_to_file {
 	# get list of components
 	my @components = split( /::/, $module );
 
-	# cwd/lib/a/b.pm under UNI*X
+	# cwd/lib/a/b.pm under UNI*
 	my $cwd = getcwd();
 	my $file = File::Spec->catfile( $cwd, 'lib', @components );
 	$file .= '.pm';
@@ -244,7 +282,7 @@ L<Test::Version> tests if there is a VERSION defined.
 L<Test::HasVersion> does it, too, but has the ability to
 check all Perl modules in C<lib>.
 
-Neiter of these compare versions.
+Neither of these compare versions.
 
 =head2 COPYRIGHT
 
